# Changelog

### [0.5.2](https://www.github.com/bihealth/django-plugins/compare/v0.5.1...v0.5.2) (2024-01-25)


### Continuous Integration

* install setuptools in release-please for py312 ([7164824](https://www.github.com/bihealth/django-plugins/commit/7164824308386b427e74944fbe17fce1857ec358))

### [0.5.1](https://www.github.com/bihealth/django-plugins/compare/v0.5.0...v0.5.1) (2024-01-25)


### Miscellaneous Chores

* re-release for pypi 0.5.1 ([c2e54df](https://www.github.com/bihealth/django-plugins/commit/c2e54dfedae44a8b04f1230acbaee632aa71d32e))

## [0.5.0](https://www.github.com/bihealth/django-plugins/compare/v0.4.0...v0.5.0) (2024-01-10)


### Features

* update for Django 4.2 compatibility ([#10](https://www.github.com/bihealth/django-plugins/issues/10)) ([#11](https://www.github.com/bihealth/django-plugins/issues/11)) ([420de5d](https://www.github.com/bihealth/django-plugins/commit/420de5dbbd72c7585af58b47f3cf41e2e174cd82))

## [0.4.0](https://www.github.com/bihealth/django-plugins/compare/v0.3.1...v0.4.0) (2023-07-18)


### Features

* cleanup setup, bump to 0.4.0 ([#8](https://www.github.com/bihealth/django-plugins/issues/8)) ([c9b0f6b](https://www.github.com/bihealth/django-plugins/commit/c9b0f6b44848f9c680ca2e57031a418c7d06ac73))

### 0.3.1 (2023-07-18)


### Features

* release for compatibility with Django >=3,<4 ([#2](https://www.github.com/bihealth/django-plugins/issues/2)) ([#3](https://www.github.com/bihealth/django-plugins/issues/3)) ([5d2e1d3](https://www.github.com/bihealth/django-plugins/commit/5d2e1d32c0af55f002130ba4c66e8785a75d7734))
